@@ -51,11 +51,7 @@ from typing import Optional, Tuple
 from loguru import logger
 
 from pyodi.core.boxes import add_centroids
-from pyodi.core.utils import (
-    coco_ground_truth_to_dfs,
-    join_annotations_with_image_sizes,
-    load_ground_truth_file,
-)
+from pyodi.core.utils import coco_ground_truth_to_df
 from pyodi.plots.boxes import get_centroids_heatmap, plot_heatmap
 from pyodi.plots.common import plot_scatter_with_histograms
 
@@ -81,12 +77,16 @@ def ground_truth(
         output = str(Path(output) / Path(ground_truth_file).stem)
         Path(output).mkdir(parents=True, exist_ok=True)
 
-    coco_ground_truth = load_ground_truth_file(ground_truth_file)
+    df_annotations = coco_ground_truth_to_df(ground_truth_file)
 
-    df_images, df_annotations = coco_ground_truth_to_dfs(coco_ground_truth)
+    df_images = df_annotations.loc[
+        :, df_annotations.columns.str.startswith("img_")
+    ].drop_duplicates()
 
     plot_scatter_with_histograms(
         df_images,
+        x="img_width",
+        y="img_height",
         title=f"{Path(ground_truth_file).stem}: Image Shapes",
         show=show,
         output=output,
@@ -95,8 +95,6 @@ def ground_truth(
         histogram_ybins=dict(size=10),
     )
 
-    df_annotations = join_annotations_with_image_sizes(df_annotations, df_images)
-
     df_annotations = add_centroids(df_annotations)
 
     df_annotations["absolute_height"] = (
